package com.ruoyi.powerdistribution.service;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmRiskRole;

/**
 * 风险规则Service接口
 *
 * @author ruoyi
 * @date 2024-12-04
 */
public interface IPdmRiskRoleService
{
    /**
     * 查询风险规则
     *
     * @param id 风险规则主键
     * @return 风险规则
     */
    public PdmRiskRole selectPdmRiskRoleById(Long id);

    /**
     * 查询风险规则列表
     *
     * @param pdmRiskRole 风险规则
     * @return 风险规则集合
     */
    public List<PdmRiskRole> selectPdmRiskRoleList(PdmRiskRole pdmRiskRole);

    /**
     * 新增风险规则
     *
     * @param pdmRiskRole 风险规则
     * @return 结果
     */
    public int insertPdmRiskRole(PdmRiskRole pdmRiskRole);

    /**
     * 修改风险规则
     *
     * @param pdmRiskRole 风险规则
     * @return 结果
     */
    public int updatePdmRiskRole(PdmRiskRole pdmRiskRole);

    /**
     * 批量删除风险规则
     *
     * @param ids 需要删除的风险规则主键集合
     * @return 结果
     */
    public int deletePdmRiskRoleByIds(Long[] ids);

    /**
     * 删除风险规则信息
     *
     * @param id 风险规则主键
     * @return 结果
     */
    public int deletePdmRiskRoleById(Long id);
}
